$NetBSD: patch-bi,v 1.2 2002/03/28 10:11:54 jmc Exp $

--- ../gcc-2.95.3/gcc/objc/objc-act.c.orig 2000/07/26 00:19:06 1.1.1.1
+++ ../gcc-2.95.3/gcc/objc/objc-act.c 2000/08/10 21:06:50 1.2
@@ -8399,8 +8399,11 @@
       pushdecl (decl);
       rest_of_decl_compilation (decl, 0, 0, 0);
 
-      /* Make following constant read-only (why not)?  */
-      readonly_data_section ();
+      /* Make following constant read-only, if not compiling PIC. */
+      if (flag_pic)
+	data_section();
+      else
+	readonly_data_section ();
 
       exp = build1 (ADDR_EXPR, string_type_node, decl);
 
